#
# spec file for package opensbi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define target %{nil}

%if "%{target}" == ""
Name:           opensbi
%else
Name:           opensbi-%{target}
%endif
Version:        1.6
Release:        31.6
Summary:        RISC-V Open Source Supervisor Binary Interface
License:        BSD-2-Clause
Group:          System/Boot
URL:            https://github.com/riscv-software-src/opensbi
Source:         https://github.com/riscv-software-src/opensbi/archive/v%{version}.tar.gz#/opensbi-%{version}.tar.gz
ExclusiveArch:  riscv64
BuildRequires:  python3-base
%if "%{target}" != ""
BuildRequires:  u-boot-%{target}
%endif

%description
The RISC-V Supervisor Binary Interface (SBI) is the recommended interface
between:

1. A platform-specific firmware running in M-mode and a bootloader, a
hypervisor or a general-purpose OS executing in S-mode or HS-mode.
2. A hypervisor running in HS-mode and a bootloader or a general-purpose
OS executing in VS-mode.

The RISC-V SBI specification is maintained as an independent project by
the RISC-V Foundation on Github (https://github.com/riscv/riscv-sbi-doc).

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++

%description devel
The RISC-V Supervisor Binary Interface (SBI) is the recommended interface
between:

1. A platform-specific firmware running in M-mode and a bootloader, a
hypervisor or a general-purpose OS executing in S-mode or HS-mode.
2. A hypervisor running in HS-mode and a bootloader or a general-purpose
OS executing in VS-mode.

The RISC-V SBI specification is maintained as an independent project by
the RISC-V Foundation on Github (https://github.com/riscv/riscv-sbi-doc).

This package provides the development files for %{name}.

%prep
%setup -q -n opensbi-%{version}

%build
%if "%{target}" == ""
%make_build PLATFORM=generic
%else
%make_build PLATFORM=generic FW_PAYLOAD_PATH=/boot/u-boot.bin FW_FDT_PATH=/boot/u-boot.dtb
%endif

%install
%if "%{target}" == ""
make install I=%{buildroot}%{_prefix} INSTALL_LIB_PATH=%{_lib}
install -D -m 644 build/platform/generic/firmware/fw_dynamic.bin %{buildroot}%{_datadir}/opensbi/opensbi.bin
%else
install -D -m 644 build/platform/generic/firmware/fw_payload.bin %{buildroot}%{_datadir}/opensbi/opensbi-%{target}.bin
%endif

%files
%{_datadir}/opensbi

%if "%{target}" == ""
%files devel
%{_includedir}/*
%{_libdir}/*
%endif

%changelog
* Tue Dec 24 2024 Andreas Schwab <schwab@suse.de>
- Update to opensbi 1.6
  * Support for parsing riscv,isa-extensions DT property
  * Setup serial console very early in cold boot path
  * Support for multiple heaps and aligned memory allocation
  * Support for shadow stacks (Zicfiss) ISA extension
  * Support for landing pads (Zicfilp) ISA extension
  * Support for per-domain data
  * Support for double-trap (Smdbltrp/Ssdbltrp) ISA extensions
  * DT-based configurable heap size
  * Common fdt_driver and helpers for driver initialization
  * Support for SBI PMU raw event v2 (Experimental)
  * Simple FDT based mailbox driver framework
  * RPMI shared memory transport driver (Experimental)
  * RPMI system reset driver (Experimental)
  * Simple FDT based system suspend driver framework
  * RPMI system suspend driver (Experimental)
  * Simple FDT based HSM driver framework
  * RPMI HSM driver (Experimental)
  * Simple FDT based CPPC driver framework
  * RPMI CPPC driver (Experimental)
  * SBI Message Proxy (MPXY) extension (Experimental)
  * Simple FDT based MPXY driver framework
  * Common RPMI client driver for MPXY (Experimental)
  * Support for vector misaligned load/store
* Fri Aug  2 2024 Andreas Schwab <schwab@suse.de>
- Update to opensbi 1.5.1
  * Save/restore menvcfg only when it exists
  * Adjust Sscofpmf mhpmevent mask for upper 8 bits
  * Fix potential NULL pointer dereferences in SBI DBTR
  * Fix incorrect size passed to sbi_zalloc() in SBI FWFT
  * Check result of pmp_get() in is_pmp_entry_mapped()
* Sun Jun 30 2024 Andreas Schwab <schwab@suse.de>
- Update to opensbi 1.5
  * SBI debug triggers (DBTR) extension (Experimental)
  * Support to specify coldboot harts in DT
  * Relocatable FW_JUMP_ADDR and FW_JUMP_FDT_ADDR
  * Smcsrind and Smcdeleg extensions support
  * SBIUnit testing framework
  * Initial domain context management support
  * Platform specific load/store emulation callbacks
  * New trap context
  * Improved sbi_trap_error() to dump state in a nested trap
  * SBI supervisor software events (SSE) extension (Experimental)
  * Simplified wait_for_coldboot() implementation
  * Early wakeup of non-coldboot HART in the coldboot path
  * Sophgo CV18XX/SG200X series support
  * APLIC delegation DT property fix
  * Svade and Svadu extensions support
  * SBI firmware features (FWFT) extension (Experimental)
* Wed Dec 27 2023 Andreas Schwab <schwab@suse.de>
- Update to opensbi 1.4
  * Synopsys DesignWare APB GPIO driver
  * Zicntr and Zihpm support
  * Console print improvements
  * Smepmp support
  * Simple FDT based syscon regmap driver
  * Syscon based reboot and poweroff driver
  * Non-contiguous hpm counters
  * Smcntrpmf support
  * Full sparse hartid support
  * IPI improvements
  * RFENCE improvements
  * Zkr support
  * Andes custom PMU support
* Wed Jul 19 2023 Andreas Schwab <schwab@suse.de>
- Update to opensbi 1.3.1
  * ACLINT driver fix for disabled CPUs
  * SBI PMU fix for out-of-bound access
  * Designware GPIO driver
* Mon Jun 26 2023 Andreas Schwab <schwab@suse.de>
- Update to opensbi 1.3
  * Allow platform to influence cold boot HART selection
  * Starfive JH7110 platform support
  * Split RX and RW firmware regions
  * Advertise nonretentive suspend for allwinner D1 platform
  * Byteorder/endianness conversion macros
  * SBI debug console extension (Experimental)
  * Configure the PMA regions for RZ/Five platform
  * SBI system suspend extension (Experimental)
  * SBI PMU platform firmware events (Experimental)
  * SBI CPPC extension (Experimental)
  * Optimized remote TLB flushes
  * Simple heap for boot time memory allocations
  * Bring back no-map DT property for reserved memory nodes
* Sat Dec 24 2022 Andreas Schwab <schwab@suse.de>
- Update to opensbi 1.2
  * RISC-V AIA v1.0.0 support
  * Cadence UART driver
  * Platform specific PMU device operations
  * Trap handling improvements for platforms with H-extension
  * Semihosting support
  * T-HEAD C9XX PMU and CLINT support
  * FDT based drivers for Andes AE350 platform
  * Andes AE350 platform improvements
  * Allow enabling/disabling of SBI extensions via Kconfig
  * Renesas SCIF serial driver
  * Renesas RZ/Five platform support
* Sat Jun 25 2022 Andreas Schwab <schwab@suse.de>
- Update to opensbi 1.1
  * SBI PMU improvements
  * RISC-V AIA v0.3.0 draft support
  * Simple external interrupt handling framework
  * Xilinx UART-Lite driver
  * RISC-V privilege specification v1.12 support
  * RISC-V Svpbmt extension support
  * RISC-V Smstateen extension support
  * RISC-V Sstc extension support
  * RISC-V privilege specification version detection
  * Platform callback to populate HART extensions
  * Compile time C arrays support
  * Probing FDT based drivers using compile time C arrays
  * SBI HSM improvements
  * Allwinner D1 platform support
  * Trap redirection improvements related to [m|h]tinst CSR
  * SBI v1.0 specification support
* Fri Dec 24 2021 Andreas Schwab <schwab@suse.de>
- Update to opensbi 1.0
  * SBI HSM suspend as defined by SBI v0.3 specification
  * Position independent execution for firmware
  * Ticket based spinlocks
  * Simplified / reduced platform callbacks
  * ACLINT MTIMER and MSWI support
  * SBI PMU extension as defined by SBI v0.3 specification
  * Simple FDT based GPIO driver framework
  * Improved reset driver framework along with various reset drivers
  * Generic timer delay loop APIs
  * RISC-V Sscofpmf extension support
  * Simple FDT based I2C driver framework along with SiFive I2C driver
  * UART drivers for Gaisler and LiteX platforms
* Mon Aug  9 2021 Andreas Schwab <schwab@suse.de>
- Drop sifivefu540 flavor
* Mon Jan 18 2021 Andreas Schwab <schwab@suse.de>
- Update to opensbi 0.9
  * Optimized trap handler for both RV32 and RV64
  * Domain support for system-level partitioning
  * Device tree based domain configuration
  * SBI v0.3 SRST extension
  * More detailed boot-time prints
* Tue Jan 12 2021 Andreas Schwab <schwab@suse.de>
- Package generic fw_dynamic firmware
* Sat Jun 20 2020 Andreas Schwab <schwab@suse.de>
- Update to opensbi 0.8
  * Simple FDT timer driver framework
  * Simple FDT ipi driver framework
  * Simple FDT irqchip driver framework
  * Simple FDT serial framework
  * Generic FDT based platform support
  * Nuclei UX600 platform support
  * Detect HART CSRs at boot time
  * Multi-PLIC support
  * Multi-CLINT support
  * Allow multiple builtin DTBs
  * Hypervisor v0.6.1 specification support
  * Shakti C-class platform support
* Thu Jun 18 2020 Andreas Schwab <schwab@suse.de>
- Drop qemu-riscv64smode flavor
- Only install fw_dynamic firmware
* Mon Apr 20 2020 Andreas Schwab <schwab@suse.de>
- Update to opensbi 0.7
  * SBI v0.2 HSM extension
  * Simple bitops library
  * Simple bitmap library
  * Simple hartmask library
  * Sparse and discontinuous HART id support
  * Memory reservation in DTB passed to next booting stage
* Mon Feb 24 2020 Andreas Schwab <schwab@suse.de>
- Update to opensbi 0.6
  * drop qemu/sifive_u platform
- align.patch: removed
* Thu Oct 24 2019 Andreas Schwab <schwab@suse.de>
- Initial version 0.5
